@@ -5,6 +5,7 @@ import os
 
 import pkg_resources
 
+
 PREFIX = "SC-P--"
 BOOTSTRAP_STACK_NAME = "servicecatalog-puppet"
 PIPELINE_NAME = "servicecatalog-puppet-pipeline"
@@ -390,3 +391,9 @@ DESCRIBE_PORTFOLIO_SHARES = "describe-portfolio-shares"
 SCHEDULER_ALGORITHM_DEFAULT = "topological_generations"
 SPOKE_SCHEDULER_THREADS_OR_PROCESSES_DEFAULT = SCHEDULER_THREADS_OR_PROCESSES_DEFAULT
 SPOKE_SCHEDULER_ALGORITHM_DEFAULT = SCHEDULER_ALGORITHM_DEFAULT
+
+
+CACHE_LEVEL_LOW = "CACHE_LEVEL_LOW"
+CACHE_LEVEL_NORMAL = "CACHE_LEVEL_NORMAL"
+CACHE_LEVEL_HIGH = "CACHE_LEVEL_HIGH"
+CACHE_LEVEL_NO_CACHE = "CACHE_LEVEL_NO_CACHE"
