@@ -3,7 +3,7 @@
 
 import luigi
 
-from servicecatalog_puppet import aws
+from servicecatalog_puppet import aws, constants
 from servicecatalog_puppet.workflow.dependencies import tasks
 
 
@@ -11,6 +11,7 @@ class TerminateSpokeLocalPortfolioTask(tasks.TaskWithReference):
     account_id = luigi.Parameter()
     region = luigi.Parameter()
     portfolio = luigi.Parameter()
+    cachable_level = constants.CACHE_LEVEL_NORMAL
 
     def params_for_results_display(self):
         return {
@@ -19,7 +20,6 @@ class TerminateSpokeLocalPortfolioTask(tasks.TaskWithReference):
             "portfolio": self.portfolio,
             "region": self.region,
             "account_id": self.account_id,
-            "cache_invalidator": self.cache_invalidator,
         }
 
     def run(self):
